@@ -1,4 +1,4 @@
-/* $Id: ssh_global.c,v 1.1.4.1 2000/08/25 09:32:09 tls Exp $ */
+/* $Id: ssh_global.c,v 1.4 2000/09/22 01:19:01 andrew Exp $ */
 
 /*
  * Copyright 1999 RedBack Networks, Incorporated.
@@ -17,9 +17,5 @@
 #include "ssh_cipher.h"
 
 struct ssh_cipher g_cipher;
-struct sshd_context g_context;
+ssh_context_t g_context;
 int nodaemon;
-
-int g_argc;
-char **g_argv;
-
