@@ -1,4 +1,4 @@
-/* $Id: ssh_logging.h,v 1.6.2.1 2000/08/25 09:32:10 tls Exp $ */
+/* $Id: ssh_logging.h,v 1.12 2001/02/09 02:43:54 andrew Exp $ */
 
 /*
  * Copyright 1999 RedBack Networks, Incorporated.
@@ -16,6 +16,14 @@
 #ifndef _SSH_LOGGING_H
 #define _SSH_LOGGING_H
 
+#ifdef __GNUC__
+#define FUNC_DECL(x)	int __attribute__((__unused__)) __unused_variable
+#define FUNC	__FUNCTION__
+#else
+#define FUNC_DECL(x) const char *s_funct_name = STRING(x)
+#define FUNC	s_funct_name
+#endif
+
 #include <syslog.h>
 #include <stdarg.h>
 #ifndef DEBUG
@@ -23,15 +31,21 @@
 #endif
 
 extern int debuglevel;
+extern const char *g_func;
+extern struct timeval tv_start;
 
-#define SSH_DLOG(l, args)	if (debuglevel >= l) logit args
-#define SSH_ERROR 		logit
+#define SSH_DLOG(l, args) do {	\
+	if (debuglevel >= l)		\
+	{ g_func = FUNC ; logit args ;}	\
+} while(0)
 
-int loginit(char *, int);
-int logclose();
-int logit(char *, ...);
+#define SSH_ERROR	g_func = FUNC, logit
 
-void debug_nostderr();
+int loginit(const char *, int);
+int logclose(void);
+int logit(const char *, ...);
+
+void debug_nostderr(void);
 
 void debug_inc(int);
 void debug_dec(int);
