@@ -1,4 +1,4 @@
-/* $Id: ssh_paths.h,v 1.3.2.1 2000/08/25 09:32:14 tls Exp $ */
+/* $Id: ssh_paths.h,v 1.5 2000/10/21 23:09:59 andrew Exp $ */
 
 /*
  * Copyright 1999 RedBack Networks, Incorporated.
@@ -20,6 +20,6 @@
 #define PATH_HOSTKEY	"/etc/ssh_host_key"
 
 /* PATH_AUTHKEYS is realtive to user's home dir. */
-#define PATH_AUTHKEYS	"/.ssh/authorized_keys"
+#define PATH_AUTHKEYS	_PATH_SSH_USER_DIR "/authorized_keys"
 
 #endif /* _SSH_PATHS_H */
