@@ -1,4 +1,4 @@
-/* $Id: ssh_sys_bsd44+.c,v 1.78 2001/02/11 03:35:14 tls Exp $ */
+/* $Id: ssh_sys_bsd44+.c,v 1.78.2.1 2001/02/15 21:33:40 erh Exp $ */
 
 /*
  * Copyright 1999 RedBack Networks, Incorporated.
@@ -363,24 +363,34 @@ ssh_sys_execcmd(ssh_context_t * context, char *cmd, int *fds)
  * preserve PRNG state across runs; then randclean would save the state, and
  * randinit would load it, hopefully mixing in some new seed randomness.
  *
+ * XXX 02/15/2001 - Cause ssh to exit immediately if we don't have a
+ *    device from which to get random data.  
  */
 
+#ifdef UNSAFE_RANDOM
+#undef UNSAFE_RANDOM
+#endif
+
 /*
  * ssh_sys_randinit:	initialize random number generator.
  */
 void
 ssh_sys_randinit()
 {
+#ifdef UNSAFE_RANDOM
 	struct timeval tv;
+#endif
 	int urandom;
 	u_int8_t ubuf[128];
 
+#ifdef UNSAFE_RANDOM
 	gettimeofday(&tv, (struct timezone *) NULL);
 
 	ssh_rand_feed((void *) &(tv.tv_sec), sizeof(tv.tv_sec));
 	ssh_rand_feed((void *) &(tv.tv_usec), sizeof(tv.tv_usec));
 
 	memset(&tv, 0, sizeof(tv));
+#endif
 
 #if 0
 	XXX Instead of this, execute a configurable script in / etc / ssh
@@ -392,20 +402,22 @@ ssh_sys_randinit()
 
 	urandom = open(_PATH_URANDOM, O_RDONLY);
 
-	if (urandom >= 0) {
-		if (read(urandom, ubuf, sizeof(ubuf)) != sizeof(ubuf)) {
-			close(urandom);
-			goto wingit;
-		} else {
-			close(urandom);
-			ssh_rand_feed(ubuf, sizeof(ubuf));
-		}
+	if (urandom >= 0 &&
+	    read(urandom, ubuf, sizeof(ubuf)) == sizeof(ubuf))
+	{
+		close(urandom);
+		ssh_rand_feed(ubuf, sizeof(ubuf));
 	} else {
+		if (urandom >= 0)
+			close(urandom);
+#ifndef UNSAFE_RANDOM
+		SSH_ERROR("Failed to open %s for ssh_rand_feed()", _PATH_URANDOM);
+		exit(1);
+#else
 		/*
 		 * System PRNG unavailable -- seed with some more
 		 * data and pray
 		 */
-wingit:
 		{
 			int numfs, whichfs = 0;
 			struct statfs *mntbuf;
@@ -418,14 +430,17 @@ wingit:
 				whichfs++;
 			}
 		}
+#endif
 	}
 
+#ifdef UNSAFE_RANDOM
 	gettimeofday(&tv, NULL);
 
 	ssh_rand_feed((void *) &(tv.tv_usec), sizeof(tv.tv_usec));
+	memset(&tv, 0, sizeof(tv));
+#endif
 
 	memset(ubuf, 0, sizeof(ubuf));
-	memset(&tv, 0, sizeof(tv));
 }
 
 /*
@@ -445,27 +460,33 @@ ssh_sys_randclean()
 void
 ssh_sys_randadd()
 {
+#ifdef UNSAFE_RANDOM
 	struct timeval tv;
+#endif
 	int urandom;
 	u_int8_t ubuf[128];
 
 	urandom = open(_PATH_URANDOM, O_RDONLY);
 
-	if (urandom < 0) {
+	if (urandom < 0 ||
+		read(urandom, ubuf, sizeof(ubuf)) != sizeof(ubuf))
+	{ 
+		if (urandom >= 0)
+			close(urandom);
+#ifndef UNSAFE_RANDOM
+		SSH_ERROR("Failed to open %s for ssh_rand_feed()", _PATH_URANDOM);
+		exit(1);
+#else
 		gettimeofday(&tv, NULL);
 		ssh_rand_feed((void *) &(tv.tv_usec), sizeof(tv.tv_usec));
+#endif
 	} else {
-		if (read(urandom, ubuf, sizeof(ubuf)) != sizeof(ubuf)) {
-			close(urandom);
-			gettimeofday(&tv, NULL);
-			ssh_rand_feed((void *) &(tv.tv_usec),
-			    sizeof(tv.tv_usec));
-		} else {
-			close(urandom);
-			ssh_rand_feed(ubuf, sizeof(ubuf));
-		}
+		close(urandom);
+		ssh_rand_feed(ubuf, sizeof(ubuf));
 	}
+#ifdef UNSAFE_RANDOM
 	memset(&tv, 0, sizeof(struct timeval));
+#endif
 	memset(ubuf, 0, sizeof(ubuf));
 }
 
